"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.personToString = personToString;
exports.workWithInitModule = workWithInitModule;
exports.workWithInitConfig = workWithInitConfig;
exports.parseRawConfig = parseRawConfig;
const path_1 = __importDefault(require("path"));
const child_process_1 = require("child_process");
const camelcase_keys_1 = __importDefault(require("camelcase-keys"));
const fs_1 = __importDefault(require("fs"));
function personToString(person) {
    const name = person.name ?? '';
    const u = person.url ?? person.web;
    const url = u ? ` (${u})` : '';
    const e = person.email ?? person.mail;
    const email = e ? ` <${e}>` : '';
    return name + email + url;
}
function workWithInitModule(localConfig) {
    const { initModule, ...restConfig } = localConfig;
    if (initModule) {
        const filePath = path_1.default.resolve(localConfig.initModule);
        const isFileExist = fs_1.default.existsSync(filePath);
        if (['.js', '.cjs'].includes(path_1.default.extname(filePath)) && isFileExist) {
            (0, child_process_1.spawnSync)('node', [filePath], {
                stdio: 'inherit',
            });
        }
    }
    return restConfig;
}
function workWithInitConfig(localConfig) {
    const packageJson = {};
    const authorInfo = {};
    for (const localConfigKey in localConfig) {
        if (localConfigKey.startsWith('init') && localConfigKey !== 'initPackageManager') {
            const pureKey = localConfigKey.replace('init', '');
            const value = localConfig[localConfigKey];
            if (pureKey.startsWith('Author')) {
                authorInfo[pureKey.replace('Author', '')] = value;
            }
            else {
                packageJson[pureKey] = value;
            }
        }
    }
    const author = personToString((0, camelcase_keys_1.default)(authorInfo));
    if (author) {
        packageJson.author = author;
    }
    return (0, camelcase_keys_1.default)(packageJson);
}
async function parseRawConfig(rawConfig) {
    return workWithInitConfig(workWithInitModule((0, camelcase_keys_1.default)(rawConfig)));
}
//# sourceMappingURL=utils.js.map